@@ -35,6 +35,8 @@ struct {
     static real rx, ry, ux, vx, wx, wy, vy, uy, zz;
     static integer ix1, iy1, ix2, iy2, ix3, iy3, ix4, iy4;
     static real wx1, wy1, wx2, wy2, wx3, wy3, wx4, wy4;
+    static integer itr;
+    static real txm, tym, tux, tuy, txx, tyx;
     static logical limc;
     static integer image[4000], istat, ixmin, iymin;
     static logical lmiss;
@@ -59,10 +61,11 @@ struct {
     extern /* Subroutine */ int swqimc_(logical *), uwdflt_(integer *, 
 	    integer *), swicls_(void), swfint_(real *, real *, integer *, 
 	    integer *), stitrf_(real *, real *, real *, real *), swiint_(
-	    integer *, integer *, real *, real *), swiopn_(integer *, integer 
-	    *, integer *, integer *, real *, real *, real *, real *, real *, 
-	    real *, real *, real *), sgqvpt_(real *, real *, real *, real *), 
-	    stfwtr_(real *, real *, real *, real *), stiwtr_(real *, real *, 
+	    integer *, integer *, real *, real *), sgqtrn_(integer *), 
+	    swiopn_(integer *, integer *, integer *, integer *, real *, real *
+	    , real *, real *, real *, real *, real *, real *), sgqvpt_(real *,
+	     real *, real *, real *), stfwtr_(real *, real *, real *, real *),
+	     stiwtr_(real *, real *, real *, real *), sgqtxy_(real *, real *, 
 	    real *, real *);
 
     /* Parameter adjustments */
@@ -121,6 +124,48 @@ struct {
     swiopn_(&ixmin, &iymin, &iwidth, &ihight, &wx1, &wy1, &wx2, &wy2, &wx3, &
 	    wy3, &wx4, &wy4);
 /*     / LOOP FOR EACH PIXEL / */
+    sgqtrn_(&itr);
+    sgqtxy_(&txm, &txx, &tym, &tyx);
+L362:
+    if (txm < -180.f) {
+	txm += 360.f;
+    }
+    if (txm > 180.f) {
+	txm += -360.f;
+    }
+    if (txm < -180.f || txm > 180.f) {
+	goto L362;
+    }
+L363:
+    if (txx < -180.f) {
+	txx += 360.f;
+    }
+    if (txx > 180.f) {
+	txx += -360.f;
+    }
+    if (txx < 180.f || txx > 180.f) {
+	goto L363;
+    }
+L365:
+    if (tym < -90.f) {
+	tym += 180.f;
+    }
+    if (tym > 90.f) {
+	tym += -180.f;
+    }
+    if (tym < -90.f || tym > 90.f) {
+	goto L365;
+    }
+L366:
+    if (tyx < -90.f) {
+	tyx += 180.f;
+    }
+    if (tyx > 90.f) {
+	tyx += -180.f;
+    }
+    if (tyx < -90.f || tyx > 90.f) {
+	goto L366;
+    }
     i__1 = ihight;
     for (j = 1; j <= i__1; ++j) {
 	i__2 = iwidth;
@@ -135,12 +180,37 @@ struct {
 	    } else {
 		stitrf_(&vx, &vy, &ux, &uy);
 	    }
+	    tux = ux;
+	    tuy = uy;
+L361:
+	    if (tux < -180.f) {
+		tux += 360.f;
+	    }
+	    if (tux > 180.f) {
+		tux += -360.f;
+	    }
+	    if (tux < -180.f || tux > 180.f) {
+		goto L361;
+	    }
+L364:
+	    if (tuy < -90.f) {
+		tuy += 180.f;
+	    }
+	    if (tuy > 90.f) {
+		tuy += -180.f;
+	    }
+	    if (tuy < -90.f || tuy > 90.f) {
+		goto L364;
+	    }
 	    if (ux == rundef) {
 		image[i__ - 1] = 0;
 	    } else {
 		ix = iuwgx_(&ux);
 		iy = iuwgy_(&uy);
-		if (ix == iundef || iy == iundef) {
+		if ((tux < txm || tux > txx || tuy < tym || tuy > tyx) && itr 
+			>= 5) {
+		    image[i__ - 1] = 0;
+		} else if (ix == iundef || iy == iundef) {
 		    image[i__ - 1] = 0;
 		} else {
 		    zz = z__[ix + iy * z_dim1];
