@@ -38,7 +38,7 @@ struct {
     static integer ix1, iy1, ix2, iy2, ix3, iy3, ix4, iy4;
     static real wx1, wy1, wx2, wy2, wx3, wy3, wx4, wy4;
     static integer itr;
-    static real uyn, uyx;
+    static real txm, tym, uyn, tux, tuy, txx, tyx, uyx;
     static logical limc;
     static integer image[4000], istat, ixmin, iymin;
     static logical lmiss;
@@ -67,7 +67,8 @@ struct {
 	    , real *, real *, real *, real *, real *, real *), sgqvpt_(real *,
 	     real *, real *, real *), uwqgxi_(real *, integer *, real *), 
 	    uwqgyi_(real *, integer *, real *), stfwtr_(real *, real *, real *
-	    , real *), stiwtr_(real *, real *, real *, real *);
+	    , real *), stiwtr_(real *, real *, real *, real *), sgqtxy_(real *
+	    , real *, real *, real *);
 
     /* Parameter adjustments */
     z_dim1 = *mx;
@@ -125,6 +126,47 @@ struct {
     swiopn_(&ixmin, &iymin, &iwidth, &ihight, &wx1, &wy1, &wx2, &wy2, &wx3, &
 	    wy3, &wx4, &wy4);
 /*     / LOOP FOR EACH PIXEL / */
+    sgqtxy_(&txm, &txx, &tym, &tyx);
+L362:
+    if (txm < -180.f) {
+	txm += 360.f;
+    }
+    if (txm > 180.f) {
+	txm += -360.f;
+    }
+    if (txm < -180.f || txm > 180.f) {
+	goto L362;
+    }
+L363:
+    if (txx < -180.f) {
+	txx += 360.f;
+    }
+    if (txx > 180.f) {
+	txx += -360.f;
+    }
+    if (txx < 180.f || txx > 180.f) {
+	goto L363;
+    }
+L365:
+    if (tym < -90.f) {
+	tym += 180.f;
+    }
+    if (tym > 90.f) {
+	tym += -180.f;
+    }
+    if (tym < -90.f || tym > 90.f) {
+	goto L365;
+    }
+L366:
+    if (tyx < -90.f) {
+	tyx += 180.f;
+    }
+    if (tyx > 90.f) {
+	tyx += -180.f;
+    }
+    if (tyx < -90.f || tyx > 90.f) {
+	goto L366;
+    }
     i__1 = ihight;
     for (j = 1; j <= i__1; ++j) {
 	i__2 = iwidth;
@@ -160,9 +202,34 @@ L360:
 			goto L360;
 		    }
 		}
+		tux = ux;
+		tuy = uy;
+L361:
+		if (tux < -180.f) {
+		    tux += 360.f;
+		}
+		if (tux > 180.f) {
+		    tux += -360.f;
+		}
+		if (tux < -180.f || tux > 180.f) {
+		    goto L361;
+		}
+L364:
+		if (tuy < -90.f) {
+		    tuy += 180.f;
+		}
+		if (tuy > 90.f) {
+		    tuy += -180.f;
+		}
+		if (tuy < -90.f || tuy > 90.f) {
+		    goto L364;
+		}
 		uwqgxi_(&ux, &ix, &fx);
 		uwqgyi_(&uy, &iy, &fy);
-		if (ix == iundef || iy == iundef) {
+		if ((tux < txm || tux > txx || tuy < tym || tuy > tyx) && itr 
+			>= 5) {
+		    image[i__ - 1] = 0;
+		} else if (ix == iundef || iy == iundef) {
 		    image[i__ - 1] = 0;
 		} else {
 		    if (lmiss && (z__[ix + iy * z_dim1] == rmiss || z__[ix + 
